@@ -235,7 +235,7 @@ class RegexDocumenter(VariableDocumenter):
 
 		# add content from docstrings
 		if not no_docstring:
-			docstrings = self.get_doc()
+			docstrings = self.get_doc() or []
 			if not docstrings:
 				# append at least a dummy docstring, so that the event
 				# autodoc-process-docstring is fired and can add some
@@ -370,7 +370,7 @@ class RegexParser:
 	* ``LITERAL_COLOUR`` -- Used for literal characters.
 	* ``ANY_COLOUR`` -- Used for the "any" dot.
 
-	These are all :class:`~typing.Callable`\[[:class:`~typing.Any`], :class:`~typing.str`\].
+	These are all :class:`~typing.Callable`\[[:class:`~typing.Any`], :class:`str`\].
 
 	By default no formatting is performed.
 	"""
@@ -813,7 +813,7 @@ def configure(app: Sphinx, config: Config):
 	:param config:
 	"""
 
-	latex_elements = getattr(app.config, "latex_elements", {})  # type: ignore
+	latex_elements = getattr(app.config, "latex_elements", {})
 
 	latex_preamble = StringList(latex_elements.get("preamble", ''))
 	latex_preamble.blankline()
