@@ -21,7 +21,7 @@ The changes are:
 * :class:`typing.TypeVar`\s are linked to if they have been included in the documentation.
 
 * If a function/method argument has a :class:`module <types.ModuleType>`, :class:`class <typing.Type>`
-  or :class:`function <types.FunctionType>` object as its default value a better
+  or :py:obj:`function <types.FunctionType>` object as its default value a better
   representation will be shown in the signature.
 
   For example:
@@ -120,6 +120,9 @@ from tempfile import TemporaryDirectory
 from types import FunctionType, ModuleType
 from typing import Any, AnyStr, Callable, Dict, List, Optional, Tuple, Type, TypeVar, get_type_hints
 
+# 3rd party
+from domdf_python_tools.stringlist import DelimitedList
+
 if sys.version_info < (3, 7, 4):  # pragma: no cover (py37+)
 	# stdlib
 	from typing import _ForwardRef as ForwardRef  # type: ignore
@@ -262,7 +265,12 @@ def format_annotation(annotation, fully_qualified: bool = False) -> str:
 	Format a type annotation.
 
 	:param annotation:
-	:param fully_qualified:
+	:param fully_qualified: Whether the fully qualified name should be shown (e.g. ``typing.List``)
+		or only the object name (e.g. ``List``).
+
+	:rtype:
+
+	.. versionchanged:: 2.13.0  Added support for :py:obj:`True` and :py:obj:`False`
 	"""
 
 	prefix = '' if fully_qualified else '~'
@@ -270,6 +278,8 @@ def format_annotation(annotation, fully_qualified: bool = False) -> str:
 	# Special cases
 	if annotation is None or annotation is type(None):  # noqa: E721
 		return ":py:obj:`None`"
+	elif isinstance(annotation, bool):
+		return f":py:obj:`{annotation}`"
 	elif annotation is Ellipsis:
 		return "..."
 	elif annotation is itertools.cycle:
@@ -313,9 +323,8 @@ def format_annotation(annotation, fully_qualified: bool = False) -> str:
 		module = "io"
 	elif module == "_ast":
 		module = "ast"
-
 	# Redirect all typing_extensions types to the stdlib typing module
-	if module == "typing_extensions":
+	elif module == "typing_extensions":
 		module = "typing"
 
 	full_name = (module + '.' + class_name) if module != "builtins" else class_name
@@ -346,8 +355,17 @@ def format_annotation(annotation, fully_qualified: bool = False) -> str:
 		formatted_args = "\\[\\[" + ", ".join(format_annotation(arg) for arg in args[:-1]) + ']'
 		formatted_args += ", " + format_annotation(args[-1]) + ']'
 	elif full_name == "typing.Literal":
-		# TODO: Bool, Enums?
-		formatted_args = "\\[" + ", ".join(code_repr(arg) for arg in args) + ']'
+		# TODO: Enums?
+		formatted_arg_list: DelimitedList[str] = DelimitedList()
+		for arg in args:
+			if isinstance(arg, bool):
+				formatted_arg_list.append(format_annotation(arg))
+			else:
+				formatted_arg_list.append(code_repr(arg))
+
+		formatted_args = f"\\[{formatted_arg_list:, }]"
+
+	# TODO: unions with one or more forward refs
 
 	if args and not formatted_args:
 		formatted_args = args_format.format(", ".join(format_annotation(arg, fully_qualified) for arg in args))
@@ -634,7 +652,7 @@ def process_docstring(
 
 			formatted_annotation = format_annotation(
 					annotation,
-					fully_qualified=app.config.typehints_fully_qualified,  # type: ignore
+					fully_qualified=app.config.typehints_fully_qualified,
 					)
 
 			searchfor = [f":{field} {argname}:" for field in ("param", "parameter", "arg", "argument")]
@@ -645,7 +663,7 @@ def process_docstring(
 					insert_index = i
 					break
 
-			if insert_index is None and app.config.always_document_param_types:  # type: ignore
+			if insert_index is None and app.config.always_document_param_types:
 				lines.append(f":param {argname}:")
 				insert_index = len(lines)
 
@@ -659,7 +677,7 @@ def process_docstring(
 
 			formatted_annotation = format_annotation(
 					type_hints["return"],
-					fully_qualified=app.config.typehints_fully_qualified,  # type: ignore
+					fully_qualified=app.config.typehints_fully_qualified,
 					)
 
 			insert_index = len(lines)
@@ -676,7 +694,7 @@ def process_docstring(
 				elif line.startswith(":return:") or line.startswith(":returns:"):
 					insert_index = i
 
-			if insert_index is not None and app.config.typehints_document_rtype:  # type: ignore
+			if insert_index is not None and app.config.typehints_document_rtype:
 
 				if insert_index == len(lines):
 					# Ensure that :rtype: doesn't get joined with a paragraph of text, which
@@ -684,7 +702,7 @@ def process_docstring(
 					lines.append('')
 					insert_index += 1
 
-				if not (formatted_annotation == ":py:obj:`None`" and app.config.hide_none_rtype):  # type: ignore
+				if not (formatted_annotation == ":py:obj:`None`" and app.config.hide_none_rtype):
 					lines.insert(insert_index, f":rtype: {formatted_annotation}")
 
 
